##  Syncing Data Between Jira and SAP LeanIX
After setting up the integration, you can import Jira work items as new initiative fact sheets, export fact sheets as Jira work items, or link two existing items. This sets up data synchronization between the specific items.
Once you connect an initiative to a work item, mapped data automatically syncs every 30 minutes.
For detailed instructions, refer to [Importing, Exporting, and Linking Fact Sheets and Jira Work Items](https://help.sap.com/docs/leanix/ea/creating-and-linking-fact-sheets-and-jira-issues?locale=en-US&state=PRODUCTION&version=CLOUD "Set up syncing between SAP LeanIX and Jira by creating new fact sheets or Jira work items, or by linking existing items across both tools.").
